@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Sequence
 
 from .literals import StatementStatusStringType, StatusStringType
 
@@ -59,7 +59,7 @@ _RequiredBatchExecuteStatementInputRequestTypeDef = TypedDict(
     {
         "ClusterIdentifier": str,
         "Database": str,
-        "Sqls": List[str],
+        "Sqls": Sequence[str],
     },
 )
 _OptionalBatchExecuteStatementInputRequestTypeDef = TypedDict(
@@ -211,7 +211,7 @@ _OptionalExecuteStatementInputRequestTypeDef = TypedDict(
     "_OptionalExecuteStatementInputRequestTypeDef",
     {
         "DbUser": str,
-        "Parameters": List["SqlParameterTypeDef"],
+        "Parameters": Sequence["SqlParameterTypeDef"],
         "SecretArn": str,
         "StatementName": str,
         "WithEvent": bool,
